@@ -292,27 +292,11 @@ public:
      */
     static int startDetached(const QStringList &argv);
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 78)
-    /**
-     * Obtain the process' ID as known to the system.
-     *
-     * Unlike with QProcess::pid(), this is a real PID also on Windows.
-     *
-     * This function can be called only while the process is running.
-     * It cannot be applied to detached processes.
-     *
-     * @return the process ID
-     * @deprecated since 5.78, use processId()
-     */
-    KCOREADDONS_DEPRECATED_VERSION(5, 78, "Use processId()")
-    int pid() const;
-#endif
-
 protected:
     /**
      * @internal
      */
-    KProcess(KProcessPrivate *d, QObject *parent);
+    KCOREADDONS_NO_EXPORT KProcess(KProcessPrivate *d, QObject *parent);
 
     /**
      * @internal
@@ -321,10 +305,6 @@ protected:
 
 private:
     // hide those
-#if QT_DEPRECATED_SINCE(5, 13) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    using QProcess::readChannelMode;
-    using QProcess::setReadChannelMode;
-#endif
     using QProcess::processChannelMode;
     using QProcess::setProcessChannelMode;
 };
